@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for ec2-instance-connect service client
 
@@ -10,11 +11,11 @@ Usage::
     client: EC2InstanceConnectClient = boto3.client("ec2-instance-connect")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING, Type
-from botocore.exceptions import ClientError as Boto3ClientError
-from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
+from typing import Any, Dict, Type
 
+from botocore.exceptions import ClientError as Boto3ClientError
+
+from mypy_boto3_ec2_instance_connect.type_defs import SendSSHPublicKeyResponseTypeDef
 
 __all__ = ("EC2InstanceConnectClient",)
 
